@@ -1,3 +1,4 @@
+#' @rdname spec_res
 #' @title Spectral resolution
 #'
 #' @description
@@ -9,22 +10,37 @@
 #' frequency difference between two lines in a spectrum that can still be
 #' distinguished.
 #'
-#' @param x a numeric vector or an \R object which is coercible to one by
-#' \code{as.vector(x, "numeric")}; \code{x} should be \code{wavenumber} data.
+#' @param x a numeric vector with \code{wavenumber} data or an \code{OpenSpecy}
+#' object.
+#' @param \ldots further arguments passed to subfunctions; currently not used.
 #'
 #' @return
 #' \code{spec_res()} returns a single numeric value.
 #'
 #' @examples
 #' data("raman_hdpe")
-#' spec_res(raman_hdpe$wavenumber)
+#'
+#' spec_res(raman_hdpe)
 #'
 #' @author
 #' Win Cowger, Zacharias Steinmetz
 #'
-#' @importFrom dplyr %>%
 #' @export
-spec_res <- function(x) {
-  (max(x) - min(x)) / length(x)
+spec_res <- function(x, ...) {
+  UseMethod("spec_res")
 }
 
+#' @rdname spec_res
+#'
+#' @export
+spec_res.default <- function(x, ...) {
+  freq <- diff(x) |> table()
+  as.numeric(names(freq)[which.max(freq)])
+}
+
+#' @rdname spec_res
+#'
+#' @export
+spec_res.OpenSpecy <- function(x, ...) {
+  do.call("spec_res", list(x = x$wavenumber))
+}
