@@ -1,4 +1,7 @@
 library(testthat)
 library(OpenSpecy)
 
+library(data.table)
+setDTthreads(2)
+
 test_check("OpenSpecy")
